﻿using System.Collections;
using System.ComponentModel;
using DeleteFromEntitySet.Web;
using Telerik.Windows.Controls;
using System.Windows.Input;
using Microsoft.Practices.Composite.Presentation.Commands;

namespace DeleteFromEntitySet
{
    public class MyViewModel : ViewModelBase
    {
        private readonly ChinookContext context;

		public ActionCommand SubmitChangesCommand { get; private set; }
		public ActionCommand RejectChangesCommand { get; private set; }

		private EntityCollectionViewBase<Artist> artists;

        public MyViewModel()
        {
            this.context = new ChinookContext();
            this.context.PropertyChanged += OnContextPropertyChanged;

			this.SubmitChangesCommand = new ActionCommand(() => this.context.SubmitChanges(), () => this.context.HasChanges);
			this.RejectChangesCommand = new ActionCommand(() => this.context.RejectChanges(), () => this.context.HasChanges);
		}

        void OnContextPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            if (e.PropertyName == "IsLoading")
            {
                this.IsLoading = this.context.IsLoading;
            }
			else if (e.PropertyName == "IsSubmitting")
			{
				this.IsLoading = this.context.IsSubmitting;
			}
			else if (e.PropertyName == "HasChanges")
			{
				this.SubmitChangesCommand.RaiseCanExecuteChanged();
				this.RejectChangesCommand.RaiseCanExecuteChanged();
			}
        }

        public IEnumerable Artists 
        {
            get
            {
                if (this.artists == null)
                {
					this.artists = new EntitySetCollectionView<Artist>(this.context.Artists);

                    this.context.Load(this.context.GetArtistsQuery());
                }

                return artists;
            }
        }

        private bool isLoading;

        public bool IsLoading
        {
            get
            {
                return this.isLoading;
            }
            private set
            {
                if (this.isLoading != value)
                {
                    this.isLoading = value;
                    this.OnPropertyChanged("IsLoading");
                }
            }
        }
    }
}
